==> qmmp-plugin-pack-1.5.0.tar.bz2: qmmp-plugin-pack-1.5.0/src/Engines/ffvideo/translations/ffvideo_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>FFVideoFactory</name>
    <message>
        <location filename="../ffvideofactory.cpp" line="42"/>
        <source>FFmpeg Video Plugin</source>
        <translation>Greffon vidéo FFmpeg</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="46"/>
        <source>Video Files</source>
        <translation>Fichiers vidéo</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="155"/>
        <source>About FFVideo Plugin</source>
        <translation>À propos du greffon FFVidéo</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="156"/>
        <source>FFmpeg-based video plugin for Qmmp</source>
        <translation>Greffon vidéo basé sur FFmpeg pour Qmmp</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="157"/>
        <source>Compiled against:</source>
        <translation>Compilé contre :</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="167"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Écrit par : Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FFVideoMetaDataModel</name>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation>Taille du fichier</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="51"/>
        <source>Bitrate</source>
        <translation>Taux de bit</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="70"/>
        <source>Audio bitrate</source>
        <translation>Débit Audio</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="71"/>
        <source>Audio sample rate</source>
        <translation>Taux d’échantillonnage audio</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="50"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="51"/>
        <location filename="../ffvideometadatamodel.cpp" line="70"/>
        <location filename="../ffvideometadatamodel.cpp" line="79"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="71"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="72"/>
        <source>Audio channels</source>
        <translation>Cannaux audio</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="78"/>
        <source>Video size</source>
        <translation>Taille de la vidéo</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="79"/>
        <source>Video bitrate</source>
        <translation>Débit vidéo</translation>
    </message>
</context>
<context>
    <name>VideoWindow</name>
    <message>
        <location filename="../videowindow.cpp" line="40"/>
        <source>FFmpeg Video</source>
        <translation>Vidéo FFmpeg</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="45"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="45"/>
        <source>Space</source>
        <translation>Espace</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="46"/>
        <source>&amp;Stop</source>
        <translation>&amp;Arrêter</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="46"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="48"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Plein écran</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="48"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack-1.5.3.tar.bz2: qmmp-plugin-pack-1.5.3/src/Engines/ffvideo/translations/ffvideo_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>FFVideoFactory</name>
    <message>
        <location filename="../ffvideofactory.cpp" line="42"/>
        <source>FFmpeg Video Plugin</source>
        <translation>Greffon vidéo FFmpeg</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="46"/>
        <source>Video Files</source>
        <translation>Fichiers vidéo</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="155"/>
        <source>About FFVideo Plugin</source>
        <translation>À propos du greffon FFVideo</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="156"/>
        <source>FFmpeg-based video plugin for Qmmp</source>
        <translation>Greffon vidéo basé sur FFmpeg pour Qmmp</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="157"/>
        <source>Compiled against:</source>
        <translation>Compilé contre :</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="167"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Écrit par : Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FFVideoMetaDataModel</name>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation>Taille du fichier</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="51"/>
        <source>Bitrate</source>
        <translation>Taux de bit</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="70"/>
        <source>Audio bitrate</source>
        <translation>Débit Audio</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="71"/>
        <source>Audio sample rate</source>
        <translation>Taux d’échantillonnage audio</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="50"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="51"/>
        <location filename="../ffvideometadatamodel.cpp" line="70"/>
        <location filename="../ffvideometadatamodel.cpp" line="79"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="71"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="72"/>
        <source>Audio channels</source>
        <translation>Cannaux audio</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="78"/>
        <source>Video size</source>
        <translation>Taille de la vidéo</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="79"/>
        <source>Video bitrate</source>
        <translation>Débit vidéo</translation>
    </message>
</context>
<context>
    <name>VideoWindow</name>
    <message>
        <location filename="../videowindow.cpp" line="40"/>
        <source>FFmpeg Video</source>
        <translation>Vidéo FFmpeg</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="45"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="45"/>
        <source>Space</source>
        <translation>Espace</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="46"/>
        <source>&amp;Stop</source>
        <translation>&amp;Arrêter</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="46"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="48"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Plein écran</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="48"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
</TS>
